@@ -13,7 +13,7 @@ from peewee_migrate import Router
 
 from .fields import Choices, JSONField  # noqa
 
-__version__ = "0.6.5"
+__version__ = "0.6.8"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -151,10 +151,6 @@ class Plugin(BasePlugin):
     def get_middleware(self) -> Callable:
         """Generate a middleware to manage connection/transaction."""
 
-        async def middleware(handler, request, receive, send):
-            async with self.connection():
-                return await handler(request, receive, send)
-
         if self.cfg.auto_transaction:
 
             async def middleware(handler, request, receive, send):
@@ -162,4 +158,10 @@ class Plugin(BasePlugin):
                     async with self.transaction():
                         return await handler(request, receive, send)
 
+        else:
+
+            async def middleware(handler, request, receive, send):
+                async with self.connection():
+                    return await handler(request, receive, send)
+
         return middleware
